package com.future.common.core.domain;

import com.future.common.constant.HttpStatus;
import com.future.common.utils.StringUtils;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;

@ApiModel("实体返回")
public class AjaxResultVo<T> {
    /**
     * 状态码
     */
    @ApiModelProperty("状态码")
    private int code;
    /**
     * 消息
     */

    @ApiModelProperty(" 消息")
    private String msg;

    /**
     * 数据对象
     */
    @ApiModelProperty("数据对象")
    private T data;

    public int getCode() {
        return code;
    }

    public void setCode(int code) {
        this.code = code;
    }

    public String getMsg() {
        return msg;
    }

    public void setMsg(String msg) {
        this.msg = msg;
    }

    public T getData() {
        return data;
    }

    public void setData(T data) {
        this.data = data;
    }

    /**
     * 初始化一个新创建的 AjaxResultVo 对象，使其表示一个空消息。
     */
    public AjaxResultVo() {
    }

    /**
     * 初始化一个新创建的 AjaxResultVo 对象
     *
     * @param code 状态码
     * @param msg  返回内容
     */
    public AjaxResultVo(int code, String msg) {
        this.code = code;
        this.msg = msg;
    }

    /**
     * 初始化一个新创建的 AjaxResultVo 对象
     *
     * @param code 状态码
     * @param msg  返回内容
     * @param data 数据对象
     */
    public AjaxResultVo(int code, String msg, T data) {
        this.code = code;
        this.msg = msg;
        if (StringUtils.isNotNull(data)) {
            this.data = data;
        }
    }

    /**
     * 返回成功消息
     *
     * @return 成功消息
     */
    public static AjaxResultVo success() {
        return AjaxResultVo.success("操作成功");
    }

    /**
     * 返回成功数据
     *
     * @return 成功消息
     */
    public static <T> AjaxResultVo success(T data) {
        return AjaxResultVo.success("操作成功" , data);
    }

    /**
     * 返回成功消息
     *
     * @param msg 返回内容
     * @return 成功消息
     */
    public static AjaxResultVo success(String msg) {
        return AjaxResultVo.success(msg, null);
    }

    /**
     * 返回成功消息
     *
     * @param msg  返回内容
     * @param data 数据对象
     * @return 成功消息
     */
    public static <T> AjaxResultVo success(String msg, T data) {

        return new AjaxResultVo(HttpStatus.SUCCESS, msg, data);
    }

    /**
     * 返回错误消息
     *
     * @return
     */
    public static AjaxResultVo error() {
        return AjaxResultVo.error("操作失败");
    }

    /**
     * 返回错误消息
     *
     * @param msg 返回内容
     * @return 警告消息
     */
    public static AjaxResultVo error(String msg) {
        return AjaxResultVo.error(msg, null);
    }

    /**
     * 返回错误消息
     *
     * @param msg  返回内容
     * @param data 数据对象
     * @return 警告消息
     */
    public static AjaxResultVo error(String msg, Object data) {
        return new AjaxResultVo(HttpStatus.ERROR, msg, data);
    }

    /**
     * 返回错误消息
     *
     * @param code 状态码
     * @param msg  返回内容
     * @return 警告消息
     */
    public static AjaxResultVo error(int code, String msg) {
        return new AjaxResultVo(code, msg, null);
    }
}
